@@ -120,7 +120,6 @@ const Application = new Lang.Class({
         GLib.set_application_name(_("Documents"));
 
         this.parent({ application_id: 'org.gnome.Documents',
-                      flags: Gio.ApplicationFlags.IS_SERVICE,
                       inactivity_timeout: 12000 });
 
         this._searchProvider = new ShellSearchProvider.ShellSearchProvider();
@@ -304,7 +303,7 @@ const Application = new Lang.Class({
         this.emitJS('miners-changed', this.minersRunning);
 
         miner._cancellable = new Gio.Cancellable();
-        miner.RefreshDBRemote(miner._cancellable, Lang.bind(this,
+        miner.RefreshDBRemote(['documents'], miner._cancellable, Lang.bind(this,
             function(res, error) {
                 this.minersRunning = this.minersRunning.filter(
                     function(element) {
