@@ -192,10 +192,13 @@ const CollectionIconWatcher = new Lang.Class({
 
         this._docs.forEach(
             function(doc) {
-                pixbufs.push(doc.origPixbuf);
+                if (doc.origPixbuf)
+                    pixbufs.push(doc.origPixbuf);
             });
 
-        this._pixbuf = GdPrivate.create_collection_icon(Utils.getIconSize(), pixbufs);
+        this._pixbuf = GdPrivate.create_collection_icon(
+            Utils.getIconSize() * Application.application.getScaleFactor(),
+            pixbufs);
         this._emitRefresh();
     },
 
@@ -227,7 +230,7 @@ const DocCommon = new Lang.Class({
         this.author = null;
         this.mtime = null;
         this.resourceUrn = null;
-        this.pixbuf = null;
+        this.surface = null;
         this.origPixbuf = null;
         this.defaultAppName = null;
 
@@ -325,20 +328,20 @@ const DocCommon = new Lang.Class({
             icon = Utils.iconFromRdfType(this.rdfType);
 
         let iconInfo =
-            Gtk.IconTheme.get_default().lookup_by_gicon(icon, Utils.getIconSize(),
-                                                        Gtk.IconLookupFlags.FORCE_SIZE |
-                                                        Gtk.IconLookupFlags.GENERIC_FALLBACK);
+            Gtk.IconTheme.get_default().lookup_by_gicon_for_scale(icon, Utils.getIconSize(),
+                                                                  Application.application.getScaleFactor(),
+                                                                  Gtk.IconLookupFlags.FORCE_SIZE |
+                                                                  Gtk.IconLookupFlags.GENERIC_FALLBACK);
 
         let pixbuf = null;
         if (iconInfo != null) {
             try {
                 pixbuf = iconInfo.load_icon();
+                this._setOrigPixbuf(pixbuf);
             } catch (e) {
                 log('Unable to load pixbuf: ' + e.toString());
             }
         }
-
-        this._setOrigPixbuf(pixbuf);
     },
 
     _refreshCollectionIcon: function() {
@@ -449,8 +452,9 @@ const DocCommon = new Lang.Class({
             function(object, res) {
                 try {
                     let stream = object.read_finish(res);
+                    let scale = Application.application.getScaleFactor();
                     GdkPixbuf.Pixbuf.new_from_stream_at_scale_async(stream,
-                        Utils.getIconSize(), Utils.getIconSize(),
+                        Utils.getIconSize() * scale, Utils.getIconSize() * scale,
                         true, null, Lang.bind(this,
                             function(object, res) {
                                 try {
@@ -483,7 +487,8 @@ const DocCommon = new Lang.Class({
     },
 
     _createSymbolicEmblem: function(name) {
-        let pix = Gd.create_symbolic_icon(name, Utils.getIconSize());
+        let pix = Gd.create_symbolic_icon(name, Utils.getIconSize() *
+                                          Application.application.getScaleFactor());
 
         if (!pix)
             pix = new Gio.ThemedIcon({ name: name });
@@ -500,8 +505,11 @@ const DocCommon = new Lang.Class({
     },
 
     _checkEffectsAndUpdateInfo: function() {
+        if (!this.origPixbuf)
+            return;
+
         let emblemIcons = [];
-        let emblemedPixbuf = null;
+        let emblemedPixbuf = this.origPixbuf;
         let activeItem;
 
         activeItem = Application.searchCategoryManager.getActiveItem();
@@ -532,8 +540,6 @@ const DocCommon = new Lang.Class({
             } catch (e) {
                 log('Unable to render the emblem: ' + e.toString());
             }
-        } else {
-            emblemedPixbuf = this.origPixbuf;
         }
 
         let thumbnailedPixbuf = null;
@@ -547,7 +553,9 @@ const DocCommon = new Lang.Class({
             thumbnailedPixbuf = emblemedPixbuf;
         }
 
-        this.pixbuf = thumbnailedPixbuf;
+        this.surface = Gdk.cairo_surface_create_from_pixbuf(thumbnailedPixbuf,
+            Application.application.getScaleFactor(),
+            Application.application.getGdkWindow());
 
         this.emit('info-updated');
     },
