@@ -85,10 +85,11 @@ const PreviewView = new Lang.Class({
 
         this.widget.show_all();
 
-        Application.application.connect('action-state-changed::bookmark-page',
+        this._bookmarkPage = Application.application.lookup_action('bookmark-page');
+        this._bookmarkPage.enabled = false;
+        this._bookmarkPage.connect('change-state',
             Lang.bind(this, this._onActionStateChanged));
-        this._onActionStateChanged(Application.application, 'bookmark-page',
-            Application.application.get_action_state('bookmark-page'));
+        this._onActionStateChanged(this._bookmarkPage, this._bookmarkPage.state);
 
         this._zoomIn = Application.application.lookup_action('zoom-in');
         this._zoomIn.connect('activate', Lang.bind(this,
@@ -146,6 +147,7 @@ const PreviewView = new Lang.Class({
     },
 
     _onLoadStarted: function() {
+        this._bookmarkPage.enabled = false;
         this._showPlaces.enabled = false;
         this._copy.enabled = false;
     },
@@ -153,13 +155,13 @@ const PreviewView = new Lang.Class({
     _onLoadFinished: function(manager, doc, docModel) {
         this._showPlaces.enabled = true;
         this._togglePresentation.enabled = true;
+        this._navControls.show();
 
         if (!Application.documentManager.metadata)
             return;
 
-        this._navControls.show();
-
         this._bookmarks = new GdPrivate.Bookmarks({ metadata: Application.documentManager.metadata });
+        this._bookmarkPage.enabled = true;
     },
 
     _onLoadError: function(manager, doc, message, exception) {
@@ -170,7 +172,7 @@ const PreviewView = new Lang.Class({
         this._loadError = false;
     },
 
-    _onActionStateChanged: function(source, actionName, state) {
+    _onActionStateChanged: function(action, state) {
         if (!this._model)
             return;
 
@@ -196,11 +198,14 @@ const PreviewView = new Lang.Class({
     _onPageChanged: function() {
         this._pageChanged = true;
 
+        if (!this._bookmarks)
+            return;
+
         let page_number = this._model.page;
         let bookmark = new GdPrivate.Bookmark({ page_number: page_number });
         let hasBookmark = (this._bookmarks.find_bookmark(bookmark) != null);
 
-        Application.application.change_action_state('bookmark-page', GLib.Variant.new('b', (hasBookmark)));
+        this._bookmarkPage.state = GLib.Variant.new('b', hasBookmark);
     },
 
     _showPlaces: function() {
@@ -548,6 +553,11 @@ const PreviewView = new Lang.Class({
         if (this._model) {
             this.view.set_model(this._model);
             this._navControls.setModel(model);
+
+            let hasMultiplePages = (this._model.document.get_n_pages() > 1);
+            this._bookmarkPage.enabled = hasMultiplePages && this._bookmarks;
+            this._showPlaces.enabled = hasMultiplePages;
+
             this._model.connect('page-changed', Lang.bind(this, this._onPageChanged));
         }
     },
@@ -614,11 +624,7 @@ const PreviewNavControls = new Lang.Class({
                                       });
         buttonArea.pack_start(button, false, false, 0);
 
-        let isRtl = (this._previewView.widget.get_direction() == Gtk.TextDirection.RTL);
-        let prevIconName = isRtl ? 'go-next-symbolic' : 'go-previous-symbolic';
-        let nextIconName = isRtl ? 'go-previous-symbolic' : 'go-next-symbolic';
-
-        this.prev_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: prevIconName,
+        this.prev_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'go-previous-symbolic',
                                                                     pixel_size: 16 }),
                                             margin_start: _PREVIEW_NAVBAR_MARGIN,
                                             margin_end: _PREVIEW_NAVBAR_MARGIN,
@@ -630,7 +636,7 @@ const PreviewNavControls = new Lang.Class({
         this.prev_widget.connect('enter-notify-event', Lang.bind(this, this._onEnterNotify));
         this.prev_widget.connect('leave-notify-event', Lang.bind(this, this._onLeaveNotify));
 
-        this.next_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: nextIconName,
+        this.next_widget = new Gtk.Button({ child: new Gtk.Image ({ icon_name: 'go-next-symbolic',
                                                                     pixel_size: 16 }),
                                             margin_start: _PREVIEW_NAVBAR_MARGIN,
                                             margin_end: _PREVIEW_NAVBAR_MARGIN,
@@ -736,13 +742,8 @@ const PreviewNavControls = new Lang.Class({
         this._model = model;
         this.bar_widget.document_model = model;
 
-        if (this._model) {
-            let hasMultiplePages = (this._model.document.get_n_pages() > 1);
-            Application.application.lookup_action('bookmark-page').enabled = hasMultiplePages;
-            Application.application.lookup_action('places').enabled = hasMultiplePages;
-
+        if (this._model)
             this._pageChangedId = this._model.connect('page-changed', Lang.bind(this, this._updateVisibility));
-        }
 
         this._updateVisibility();
     },
@@ -808,7 +809,7 @@ const PreviewToolbar = new Lang.Class({
         let previewMenu = this._getPreviewMenu();
         let menuButton = new Gd.HeaderMenuButton({ menu_model: previewMenu,
                                                    action_name: 'app.gear-menu',
-                                                   symbolic_icon_name: 'emblem-system-symbolic' });
+                                                   symbolic_icon_name: 'open-menu-symbolic' });
         this.toolbar.pack_end(menuButton);
 
         // search button, on the right of the toolbar
